@@ -85,7 +85,7 @@ class TagStatus:
 
 class TagCounter(dict):
 
-    __slots__ = ("parent", "counts", "different")
+    __slots__ = ('parent', 'counts', 'different')
 
     def __init__(self, parent):
         self.parent = parent
@@ -111,7 +111,7 @@ class TagCounter(dict):
         if tag in self.different:
             return (ngettext("(different across %d item)", "(different across %d items)", count) % count, True)
         else:
-            if tag == "~length":
+            if tag == '~length':
                 msg = format_time(self.get(tag, 0))
             else:
                 msg = MULTI_VALUED_JOINER.join(self[tag])
@@ -124,7 +124,7 @@ class TagCounter(dict):
 
 class TagDiff(object):
 
-    __slots__ = ("tag_names", "new", "orig", "status", "objects", "max_length_delta_ms")
+    __slots__ = ('tag_names', 'new', 'orig', 'status', 'objects', 'max_length_delta_ms')
 
     def __init__(self, max_length_diff=2):
         self.tag_names = []
@@ -135,7 +135,7 @@ class TagDiff(object):
         self.max_length_delta_ms = max_length_diff * 1000
 
     def __tag_ne(self, tag, orig, new):
-        if tag == "~length":
+        if tag == '~length':
             return abs(float(orig) - float(new)) > self.max_length_delta_ms
         else:
             return orig != new
@@ -204,8 +204,8 @@ class TableTagEditorDelegate(TagEditorDelegate):
 class MetadataBox(QtWidgets.QTableWidget):
 
     options = (
-        Option("persist", "metadatabox_header_state", QtCore.QByteArray()),
-        BoolOption("persist", "show_changes_first", False)
+        Option('persist', 'metadatabox_header_state', QtCore.QByteArray()),
+        BoolOption('persist', 'show_changes_first', False)
     )
 
     COLUMN_ORIG = 1
@@ -234,20 +234,21 @@ class MetadataBox(QtWidgets.QTableWidget):
         self.files = set()
         self.tracks = set()
         self.objects = set()
+        self.tag_diff = None
         self.selection_mutex = QtCore.QMutex()
         self.selection_dirty = False
         self.editing = None  # the QTableWidgetItem being edited
         self.clipboard = [""]
-        self.add_tag_action = QtWidgets.QAction(_("Add New Tag..."), parent)
+        self.add_tag_action = QtWidgets.QAction(_("Add New Tag…"), parent)
         self.add_tag_action.triggered.connect(partial(self.edit_tag, ""))
         self.changes_first_action = QtWidgets.QAction(_("Show Changes First"), parent)
         self.changes_first_action.setCheckable(True)
-        self.changes_first_action.setChecked(config.persist["show_changes_first"])
+        self.changes_first_action.setChecked(config.persist['show_changes_first'])
         self.changes_first_action.toggled.connect(self.toggle_changes_first)
-        # TR: Keyboard shortcut for "Add New Tag..."
+        # TR: Keyboard shortcut for "Add New Tag…"
         self.add_tag_shortcut = QtWidgets.QShortcut(QtGui.QKeySequence(_("Alt+Shift+A")), self, partial(self.edit_tag, ""))
         self.add_tag_action.setShortcut(self.add_tag_shortcut.key())
-        # TR: Keyboard shortcut for "Edit..." (tag)
+        # TR: Keyboard shortcut for "Edit…" (tag)
         self.edit_tag_shortcut = QtWidgets.QShortcut(QtGui.QKeySequence(_("Alt+Shift+E")), self, partial(self.edit_selected_tag))
         # TR: Keyboard shortcut for "Remove" (tag)
         self.remove_tag_shortcut = QtWidgets.QShortcut(QtGui.QKeySequence(_("Alt+Shift+R")), self, self.remove_selected_tags)
@@ -260,22 +261,22 @@ class MetadataBox(QtWidgets.QTableWidget):
     def get_file_lookup(self):
         """Return a FileLookup object."""
         config = get_config()
-        return FileLookup(self, config.setting["server_host"],
-                          config.setting["server_port"],
+        return FileLookup(self, config.setting['server_host'],
+                          config.setting['server_port'],
                           self.tagger.browser_integration.port)
 
     def lookup_tags(self):
         lookup = self.get_file_lookup()
         LOOKUP_TAGS = {
-            "musicbrainz_recordingid": lookup.recording_lookup,
-            "musicbrainz_trackid": lookup.track_lookup,
-            "musicbrainz_albumid": lookup.album_lookup,
-            "musicbrainz_workid": lookup.work_lookup,
-            "musicbrainz_artistid": lookup.artist_lookup,
-            "musicbrainz_albumartistid": lookup.artist_lookup,
-            "musicbrainz_releasegroupid": lookup.release_group_lookup,
-            "musicbrainz_discid": lookup.discid_lookup,
-            "acoustid_id": lookup.acoust_lookup
+            'musicbrainz_recordingid': lookup.recording_lookup,
+            'musicbrainz_trackid': lookup.track_lookup,
+            'musicbrainz_albumid': lookup.album_lookup,
+            'musicbrainz_workid': lookup.work_lookup,
+            'musicbrainz_artistid': lookup.artist_lookup,
+            'musicbrainz_albumartistid': lookup.artist_lookup,
+            'musicbrainz_releasegroupid': lookup.release_group_lookup,
+            'musicbrainz_discid': lookup.discid_lookup,
+            'acoustid_id': lookup.acoust_lookup
         }
         return LOOKUP_TAGS
 
@@ -370,7 +371,7 @@ class MetadataBox(QtWidgets.QTableWidget):
             if single_tag:
                 selected_tag = tags[0]
                 editable = self.tag_is_editable(selected_tag)
-                edit_tag_action = QtWidgets.QAction(_("Edit..."), self.parent)
+                edit_tag_action = QtWidgets.QAction(_("Edit…"), self.parent)
                 edit_tag_action.triggered.connect(partial(self.edit_tag, selected_tag))
                 edit_tag_action.setShortcut(self.edit_tag_shortcut.key())
                 edit_tag_action.setEnabled(editable)
@@ -433,6 +434,9 @@ class MetadataBox(QtWidgets.QTableWidget):
                     use_orig_value_action = QtWidgets.QAction(name, self.parent)
                     use_orig_value_action.triggered.connect(partial(self._apply_update_funcs, useorigs))
                     menu.addAction(use_orig_value_action)
+                    merge_tags_action = QtWidgets.QAction(_("Merge Original Values"), self)
+                    merge_tags_action.triggered.connect(partial(self._merge_tags, selected_tag))
+                    menu.addAction(merge_tags_action)
                     menu.addSeparator()
                 if single_tag:
                     menu.addSeparator()
@@ -459,8 +463,19 @@ class MetadataBox(QtWidgets.QTableWidget):
                 f()
         self.parent.update_selection(new_selection=False, drop_album_caches=True)
 
+    def _merge_tags(self, tag):
+        with self.tagger.window.ignore_selection_changes:
+            for obj in self.objects:
+                values = list(obj.orig_metadata.getall(tag))
+                for new_value in obj.metadata.getall(tag):
+                    if new_value not in values:
+                        values.append(new_value)
+                obj.metadata[tag] = values
+                obj.update()
+
     def edit_tag(self, tag):
-        EditTagDialog(self.parent, tag).exec_()
+        if self.tag_diff is not None:
+            EditTagDialog(self.parent, tag).exec_()
 
     def edit_selected_tag(self):
         tags = self.selected_tags(filter_func=self.tag_is_editable)
@@ -469,7 +484,7 @@ class MetadataBox(QtWidgets.QTableWidget):
 
     def toggle_changes_first(self, checked):
         config = get_config()
-        config.persist["show_changes_first"] = checked
+        config.persist['show_changes_first'] = checked
         self.update()
 
     def set_tag_values(self, tag, values, objects=None):
@@ -557,8 +572,8 @@ class MetadataBox(QtWidgets.QTableWidget):
             return None
 
         if new_selection or drop_album_caches:
-            self._single_file_album = len({file.metadata["album"] for file in files}) == 1
-            self._single_track_album = len({track.metadata["album"] for track in tracks}) == 1
+            self._single_file_album = len({file.metadata['album'] for file in files}) == 1
+            self._single_track_album = len({track.metadata['album'] for track in tracks}) == 1
 
         while not new_selection:  # Just an if with multiple exit points
             # If we are dealing with the same selection
@@ -582,12 +597,12 @@ class MetadataBox(QtWidgets.QTableWidget):
         }
 
         config = get_config()
-        tag_diff = TagDiff(max_length_diff=config.setting["ignore_track_duration_difference_under"])
+        tag_diff = TagDiff(max_length_diff=config.setting['ignore_track_duration_difference_under'])
         orig_tags = tag_diff.orig
         new_tags = tag_diff.new
         tag_diff.objects = len(files)
 
-        clear_existing_tags = config.setting["clear_existing_tags"]
+        clear_existing_tags = config.setting['clear_existing_tags']
         top_tags = config.setting['metadatabox_top_tags']
         top_tags_set = set(top_tags)
 
@@ -608,7 +623,7 @@ class MetadataBox(QtWidgets.QTableWidget):
                 removed = name in new_metadata.deleted_tags
                 tag_diff.add(name, orig_values, new_values, True, removed, top_tags=top_tags_set)
 
-            tag_diff.add("~length", str(orig_metadata.length), str(new_metadata.length),
+            tag_diff.add('~length', str(orig_metadata.length), str(new_metadata.length),
                          removable=False, readonly=True)
 
         for track in tracks:
@@ -622,7 +637,7 @@ class MetadataBox(QtWidgets.QTableWidget):
                         tag_diff.add(name, orig_values, new_values, True)
 
                 length = str(track.metadata.length)
-                tag_diff.add("~length", length, length, removable=False, readonly=True)
+                tag_diff.add('~length', length, length, removable=False, readonly=True)
 
                 tag_diff.objects += 1
 
@@ -631,7 +646,7 @@ class MetadataBox(QtWidgets.QTableWidget):
         tag_names = common_tags + sorted(all_tags.difference(common_tags),
                                          key=lambda x: display_tag_name(x).lower())
 
-        if config.persist["show_changes_first"]:
+        if config.persist['show_changes_first']:
             tags_by_status = {}
 
             for tag in tag_names:
@@ -685,7 +700,7 @@ class MetadataBox(QtWidgets.QTableWidget):
                 self.setItem(i, 2, new_item)
             tag_item.setText(display_tag_name(name))
             self.set_item_value(orig_item, self.tag_diff.orig, name)
-            if name == "~length":
+            if name == '~length':
                 new_item.setFlags(orig_flags)
             else:
                 new_item.setFlags(new_flags)
@@ -723,7 +738,7 @@ class MetadataBox(QtWidgets.QTableWidget):
     @restore_method
     def restore_state(self):
         config = get_config()
-        state = config.persist["metadatabox_header_state"]
+        state = config.persist['metadatabox_header_state']
         header = self.horizontalHeader()
         header.restoreState(state)
         header.setSectionResizeMode(QtWidgets.QHeaderView.ResizeMode.Interactive)
@@ -732,4 +747,4 @@ class MetadataBox(QtWidgets.QTableWidget):
         config = get_config()
         header = self.horizontalHeader()
         state = header.saveState()
-        config.persist["metadatabox_header_state"] = state
+        config.persist['metadatabox_header_state'] = state
